Learn R Programming

gld (version 2.6.6)

print.starship: Print (or summarise) the results of a starship estimation

Description

Print (or summarise) the results of a starship estimation of the parameters of the Generalised Lambda Distribution

Usage

# S3 method for starship
summary(object, ...)

# S3 method for starship print(x, digits = max(3, getOption("digits") - 3), ...)

Arguments

x

An object of class starship.

object

An object of class starship.

digits

minimal number of significant digits, see print.default.

...

arguments passed to print

Author

Robert King, [email protected], https://github.com/newystats/

Darren Wraith

Details

summary Gives the details of the starship.adaptivegrid and optim steps.

References

Freimer, M., Mudholkar, G. S., Kollia, G. & Lin, C. T. (1988), A study of the generalized tukey lambda family, Communications in Statistics - Theory and Methods 17, 3547--3567.

Ramberg, J. S. & Schmeiser, B. W. (1974), An approximate method for generating asymmetric random variables, Communications of the ACM 17, 78--82.

King, R.A.R. & MacGillivray, H. L. (1999), A starship method for fitting the generalised \(\lambda\) distributions, Australian and New Zealand Journal of Statistics 41, 353--374

Owen, D. B. (1988), The starship, Communications in Statistics - Computation and Simulation 17, 315--323.

https://github.com/newystats/gld/

See Also

starship, starship.adaptivegrid, starship.obj

Examples

Run this code
data <- rgl(100,0,1,.2,.2)
starship.result <- starship(data,optim.method="Nelder-Mead",initgrid=list(lcvect=(0:4)/10,
ldvect=(0:4)/10))
print(starship.result)
summary(starship.result,estimation.details=TRUE)

Run the code above in your browser using DataLab